contexttools.detach_clef_marks_attached_to_component
====================================================

.. autofunction:: abjad.tools.contexttools.detach_clef_marks_attached_to_component.detach_clef_marks_attached_to_component
